[![Documentation Status](https://readthedocs.org/projects/pylook/badge/?version=latest)](https://pylook.readthedocs.io/en/latest/?badge=latest)

# PyLook

To get coast
```bash
wget https://www.ngdc.noaa.gov/mgg/shorelines/data/gshhg/latest/gshhg-gmt-2.3.7.tar.gz
tar -xzvf gshhg-gmt-2.3.7.tar.gz
export GSHHS_DATA=gshhg-gmt-2.3.7
```

To install
```bash
conda install matplotlib numpy numba netCDF4 pyproj pyqt
python setup.py install
```

Executable
```bash
PyLook
```